==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/is.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Stjórna Lightbox Gallary Parameters");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "stjórna Gallerí");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Breidd");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Hæð");
define('MANAGE_GALLERY_THUMB_WIDTH', "Smámynd Breidd myndar");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Smámynd Hæð");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Varðveita Thumb hlutföllum");
define('MANAGE_GALLERY_SHOW_TITLES', "Sýna Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Slökkva Raða");
define('MANAGE_GALLERY_DELETE_IMAGE', "eyða mynd");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Geyma Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Smelltu á &#39;Uppfæra&#39; til að birta <br /> uploaded myndirnar þínar.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Allar myndir hafa verið breytt og Stillingarnar hafa verið vistaðar.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Það kom upp villa resizing myndir eða vista stillingarnar.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Mynd þín (s) hefur verið hlaðið inn.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Það kom upp villa hlaða myndinni þinni (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Skráin sem þú ert að reyna að senda inn er ekki mynd.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Skráin sem þú ert að reyna að hlaða inn er of stór.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titillinn hefur verið vistaðar.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ertu viss um að þú viljir eyða mynd");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Myndin hefur verið eytt.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Það kom upp villa við að eyða myndina.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Saving breytur og resizing myndir, bíddu ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Að hlaða upp, vinsamlegast bíðið ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "The röðunin hefur ekki verið vistaðar. Viltu vista röðina?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Myndin röðunin hefur verið vistaðar.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Það kom upp villa við að vista myndina konar.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/is.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Stjórna Lightbox Gallary Parameters");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "stjórna Gallerí");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Breidd");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Hæð");
define('MANAGE_GALLERY_THUMB_WIDTH', "Smámynd Breidd myndar");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Smámynd Hæð");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Varðveita Thumb hlutföllum");
define('MANAGE_GALLERY_SHOW_TITLES', "Sýna Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Slökkva Raða");
define('MANAGE_GALLERY_DELETE_IMAGE', "eyða mynd");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Geyma Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Smelltu á &#39;Uppfæra&#39; til að birta <br /> uploaded myndirnar þínar.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Allar myndir hafa verið breytt og Stillingarnar hafa verið vistaðar.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Það kom upp villa resizing myndir eða vista stillingarnar.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Mynd þín (s) hefur verið hlaðið inn.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Það kom upp villa hlaða myndinni þinni (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Skráin sem þú ert að reyna að senda inn er ekki mynd.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Skráin sem þú ert að reyna að hlaða inn er of stór.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Titillinn hefur verið vistaðar.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ertu viss um að þú viljir eyða mynd");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Myndin hefur verið eytt.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Það kom upp villa við að eyða myndina.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Saving breytur og resizing myndir, bíddu ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Að hlaða upp, vinsamlegast bíðið ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "The röðunin hefur ekki verið vistaðar. Viltu vista röðina?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Myndin röðunin hefur verið vistaðar.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Það kom upp villa við að vista myndina konar.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Skráin sem þú ert að reyna að hlaða upp er stærri en &#39;upload_max_filesize&#39; eða PHP stillingarnar &#39;post_max_size&#39;. Hafðu samband við kerfisstjórann þinn til að auka þessi mörk.");
?>
